@@ -101,12 +101,12 @@ def data(varName='', varContent='', codeContent=''):
 def trace(varName='', varIndex='', varContent='', pathContentStart='', pathContentEnd=''):
     varName = colored(str(varName), 'cyan')
 
-    if not varIndex:
+    if varIndex == '':
         varIndex = colored(str('None'), 'yellow')
     else:
         varIndex = colored(str(varIndex), 'yellow')
         
-    if not varContent:
+    if varContent == '':
         varContent = colored(str('None'), 'yellow')
     else:
         varContent = colored(str(varContent), 'yellow')
